Learn R Programming

PIGE (version 1.1)

list.gene.snp: Fictive list for the case-control study example containing the names of the snp for each gene included in the studied pathways

Description

Fictive list for the case-control study example containing the names of the snp for each gene included in the studied pathways

Arguments

Format

A list containing the names of the SNPs belonging to each gene analysed.