Learn R Programming

PIGE (version 1.1)

snp.gene.select: Fictive data frame containing the names of the gene (first column) and the names of the SNP belonging to the SNPS (second column)

Description

Fictive data frame containing the names of the gene (first column) and the names of the SNP belonging to the SNPS (second column)

Arguments

Format

A data frame of 130 entries corresponding of the gene's name of each SNP.